#!/usr/bin/perl -w
#
# getClients.pl
#
# Copyright (C) 2011-2013 Cesnet z.s.p.o
#
# Use of this source is governed by a BSD-style license, see LICENSE file.

use strict;
use Getopt::Std;
use DBI;
use DBD::mysql;
use FindBin qw($RealBin $RealScript);
use lib "$FindBin::RealBin/../lib";
use WardenCommon;



################################################################################
#				VARIABLES
################################################################################
our $VERSION = "2.2";
my $etc = "$FindBin::RealBin/../etc";



################################################################################
#				FUNCTIONS
################################################################################
sub usage {
  print "Usage: $RealScript [without parameters]\n";
  exit 1;
}



################################################################################
#                               MAIN
################################################################################
our ($opt_h);

die usage unless getopts("h");
my $help = $opt_h;

# catch help param
if ($help) {usage}

# superuser controle
my $UID = $<;
if ($UID != 0) {WardenCommon::errMsg("You must be root for running this script!")}

# read config file
my $conf_file = "$etc/warden-server.conf";
our $DB_NAME            = undef;
our $DB_USER            = undef;
our $DB_PASS            = undef;
our $DB_HOST            = undef;
unless (do $conf_file) {
  die("Errors in config file '$conf_file': $@") if $@;
  die("Can't read config file '$conf_file': $!") unless defined $_;
  # if $_ defined, it's retvalue of last statement of conf, for which we don't care
}

# connect to DB
our $DBH = DBI->connect("DBI:mysql:database=$DB_NAME;host=$DB_HOST", $DB_USER, $DB_PASS, {RaiseError => 1, mysql_auto_reconnect => 1})
           || die "Could not connect to database: $DBH->errstr";

# obtain data from DB
my $sth = $DBH->prepare("SELECT * FROM clients ORDER BY client_id ASC;") or die "Cannot prepare statement: " . $DBH->errstr;
$sth->execute or die "Cannot execute statement: " . $sth->errstr;
my $hash_ref = $sth->fetchall_hashref("client_id");

# print table of clients
print "+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+\n";
print "| Client ID  | Hostname                       | Registered          | Requestor               | Service                   | CT | Type            | ROE  | Description tags                                   | IP Net Client      | Valid |\n";
print "+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+\n";
foreach my $key (sort {$a<=>$b} keys %$hash_ref) {
  printf("| %-10s ", $hash_ref->{$key}->{client_id} || "unknown");
  printf("| %-30s ", $hash_ref->{$key}->{hostname} || "unknown");
  printf("| %19s ", $hash_ref->{$key}->{registered}  || "unknown");
  printf("| %-23s ", $hash_ref->{$key}->{requestor} || "unknown");
  printf("| %-25s ", $hash_ref->{$key}->{service} || "-");
  printf("| %-2s ", $hash_ref->{$key}->{client_type}  || "unknown");
  printf("| %-15s ", $hash_ref->{$key}->{type} || "-");
  printf("| %-4s ", $hash_ref->{$key}->{receive_own_events}  || "-");
  printf("| %-50s ", $hash_ref->{$key}->{description_tags} || "-");
  printf("| %-18s ", $hash_ref->{$key}->{ip_net_client}|| "unknown");
  printf("| %-5s |\n", $hash_ref->{$key}->{valid}|| "unknown");
}
print "+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+\n";
print "\n";
print "Current registered clients in: " . scalar localtime(time) . "\n";

exit 0;
